@@ -4,7 +4,8 @@ import hmac
 
 import six
 
-from .base import Algorithm
+from jose.algorithms.base import Algorithm
+from jose.utils import constant_time_compare
 
 
 class HMACAlgorithm(Algorithm):
@@ -19,7 +20,7 @@ class HMACAlgorithm(Algorithm):
     def __init__(self, hash_alg):
         self.hash_alg = hash_alg
 
-    def prepare_key(self, key):
+    def process_prepare_key(self, key):
         if not isinstance(key, six.string_types) and not isinstance(key, bytes):
             raise TypeError('Expecting a string- or bytes-formatted key.')
 
@@ -39,8 +40,8 @@ class HMACAlgorithm(Algorithm):
 
         return key
 
-    def sign(self, msg, key):
+    def process_sign(self, msg, key):
         return hmac.new(key, msg, self.hash_alg).digest()
 
-    def verify(self, msg, key, sig):
-        return sig == self.sign(msg, key)
+    def process_verify(self, msg, key, sig):
+        return constant_time_compare(sig, self.sign(msg, key))
