@@ -15,11 +15,6 @@ from .utils import base64url_decode
 def sign(claims, key, headers=None, algorithm=ALGORITHMS.HS256):
     """Signs a claims set and returns a JWS string.
 
-    Examples:
-
-        >>> jws.sign({'a': 'b'}, 'secret', algorithm='HS256')
-        'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhIjoiYiJ9.jiMyrsmD8AoHWeQgmxZ5yq8z0lXS67_QGs52AzC8Ru8'
-
     Args:
         claims (dict): A claims set to sign
         key (str): The key to use for signing the claim set
@@ -35,6 +30,11 @@ def sign(claims, key, headers=None, algorithm=ALGORITHMS.HS256):
     Raises:
         JWSError: If there is an error signing the token.
 
+    Examples:
+
+        >>> jws.sign({'a': 'b'}, 'secret', algorithm='HS256')
+        'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhIjoiYiJ9.jiMyrsmD8AoHWeQgmxZ5yq8z0lXS67_QGs52AzC8Ru8'
+
     """
 
     if algorithm not in ALGORITHMS.SUPPORTED:
@@ -50,11 +50,6 @@ def sign(claims, key, headers=None, algorithm=ALGORITHMS.HS256):
 def verify(token, key, algorithms, verify=True):
     """Verifies a JWS string's signature.
 
-    Examples:
-
-        >>> payload = 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhIjoiYiJ9.jiMyrsmD8AoHWeQgmxZ5yq8z0lXS67_QGs52AzC8Ru8'
-        >>> jws.verify(payload, 'secret', algorithms='HS256')
-
     Args:
         token (str): A signed JWS to be verified.
         key (str): A key to attempt to verify the payload with.
@@ -66,6 +61,11 @@ def verify(token, key, algorithms, verify=True):
     Raises:
         JWSError: If there is an exception verifying a token.
 
+    Examples:
+
+        >>> payload = 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhIjoiYiJ9.jiMyrsmD8AoHWeQgmxZ5yq8z0lXS67_QGs52AzC8Ru8'
+        >>> jws.verify(payload, 'secret', algorithms='HS256')
+
     """
 
     header, claims, signing_input, signature = _load(token)
@@ -108,8 +108,8 @@ def _sign_header_and_claims(encoded_header, encoded_claims, algorithm, key):
         alg_obj = get_algorithm_object(algorithm)
         key = alg_obj.prepare_key(key)
         signature = alg_obj.sign(signing_input, key)
-    except:
-        raise JWSError('Unable to sign header and claims.')
+    except Exception, e:
+        raise JWSError(e)
 
     encoded_signature = base64url_encode(signature)
 
